| /freebsd-13.1/contrib/googletest/googletest/include/gtest/ |
| H A D | gtest_pred_impl.h | 88 Pred pred, in AssertPred1Helper() argument 90 if (pred(v1)) return AssertionSuccess(); in AssertPred1Helper() 105 #define GTEST_PRED1_(pred, v1, on_failure)\ argument 114 #define EXPECT_PRED1(pred, v1) \ argument 118 #define ASSERT_PRED1(pred, v1) \ argument 131 Pred pred, in AssertPred2Helper() argument 162 #define EXPECT_PRED2(pred, v1, v2) \ argument 166 #define ASSERT_PRED2(pred, v1, v2) \ argument 181 Pred pred, in AssertPred3Helper() argument 217 #define EXPECT_PRED3(pred, v1, v2, v3) \ argument [all …]
|
| /freebsd-13.1/crypto/openssh/regress/unittests/test_helper/ |
| H A D | test_helper.c | 52 switch (pred) { \ 83 switch (pred) { \ 358 TEST_CHECK_INT(r, pred); in assert_bignum() 377 TEST_CHECK_INT(r, pred); in assert_string() 416 TEST_CHECK_INT(r, pred); in assert_mem() 456 TEST_CHECK_INT(r, pred); in assert_mem_filled() 472 TEST_CHECK(aa1, aa2, pred); in assert_int() 483 TEST_CHECK(aa1, aa2, pred); in assert_size_t() 494 TEST_CHECK(aa1, aa2, pred); in assert_u_int() 505 TEST_CHECK(aa1, aa2, pred); in assert_long() [all …]
|
| H A D | test_helper.h | 62 const char *aa1, const char *aa2, enum test_predicate pred); 71 int aa1, int aa2, enum test_predicate pred); 74 size_t aa1, size_t aa2, enum test_predicate pred); 77 u_int aa1, u_int aa2, enum test_predicate pred); 80 long aa1, long aa2, enum test_predicate pred); 83 long long aa1, long long aa2, enum test_predicate pred); 86 char aa1, char aa2, enum test_predicate pred); 92 u_int8_t aa1, u_int8_t aa2, enum test_predicate pred); 95 u_int16_t aa1, u_int16_t aa2, enum test_predicate pred); 98 u_int32_t aa1, u_int32_t aa2, enum test_predicate pred); [all …]
|
| /freebsd-13.1/contrib/llvm-project/clang/include/clang/Basic/ |
| H A D | arm_mve.td | 216 $addend, $m1, $m2_s, $pred)>; 398 $pred, 685 top, $pred)>, 704 $a, $pred, $inactive)>; 810 def _m: Intrinsic<pred, (args u32:$val, pred:$inpred), 951 $addr, $offset, $pred)>; 1291 0, $pred):$pair, 1329 $pred)>; 1449 defvar predArg = !if(pred, (args Predicate:$pred), (args)); 1450 defvar intrinsic = !if(pred, [all …]
|
| H A D | arm_cde.td | 195 argsReg, imm, (args Predicate:$pred)), 197 $cp, $inactive_or_acc), cgArgs, (? $imm, $pred))> { 211 !listconcat(["cp", "inactive"], macroArgs, ["imm", "pred"]), 212 "__arm_"#NAME#"_m_impl((cp), (inactive), "#macro#" (imm), (pred))">; 214 !listconcat(["cp", "acc"], macroArgs, ["imm", "pred"]), 215 "__arm_"#NAME#"a_m_impl((cp), (acc), "#macro#" (imm), (pred))">;
|
| /freebsd-13.1/contrib/llvm-project/llvm/lib/IR/ |
| H A D | ConstantFold.cpp | 1104 pred = CmpInst::getInversePredicate(pred); in ConstantFoldBinaryInstruction() 1468 return pred; in evaluateICmpRelation() 1472 return pred; in evaluateICmpRelation() 1476 return pred; in evaluateICmpRelation() 1777 switch(pred) { in ConstantFoldCompareInstruction() 1792 switch (pred) { in ConstantFoldCompareInstruction() 1809 switch (pred) { in ConstantFoldCompareInstruction() 1915 if (pred == FCmpInst::FCMP_UGT || pred == FCmpInst::FCMP_OGT) in ConstantFoldCompareInstruction() 1922 if (pred == FCmpInst::FCMP_ULT || pred == FCmpInst::FCMP_OLT) in ConstantFoldCompareInstruction() 1929 if (pred == FCmpInst::FCMP_OEQ || pred == FCmpInst::FCMP_UEQ) in ConstantFoldCompareInstruction() [all …]
|
| /freebsd-13.1/cddl/contrib/opensolaris/lib/libdtrace/common/ |
| H A D | dt_sugar.c | 143 dt_node_t *pred, int condid, int newcond) in dt_sugar_new_condition_impl() argument 160 value = dt_node_op2(DT_TOK_LAND, dt_node_int(1), pred); in dt_sugar_new_condition_impl() 164 dt_sugar_new_condition_var(condid), pred); in dt_sugar_new_condition_impl() 180 dt_sugar_new_condition(dt_sugar_parse_t *dp, dt_node_t *pred, int condid) in dt_sugar_new_condition() argument 184 pred, condid, dp->dtsp_num_conditions)); in dt_sugar_new_condition() 344 dt_node_t *pred = in dt_sugar_do_if() local 347 dt_sugar_new_condition(dp, pred, precondition)); in dt_sugar_do_if() 364 dt_node_t *pred = NULL; in dt_sugar_new_basic_block() local 373 pred = dt_node_op1(DT_TOK_LNEG, in dt_sugar_new_basic_block() 377 pred = dt_node_op2(DT_TOK_LAND, in dt_sugar_new_basic_block() [all …]
|
| /freebsd-13.1/contrib/llvm-project/llvm/lib/Target/ARM/ |
| H A D | ARMInstrThumb2.td | 412 // pred operand excluding AL 1401 (ins t2adrlabel:$addr, pred:$p), 4818 pred:$p, cc_out:$s)>; 4825 pred:$p, cc_out:$s)>; 4837 pred:$p, cc_out:$s)>; 4849 pred:$p, cc_out:$s)>; 4884 pred:$p, cc_out:$s)>; 4898 pred:$p, cc_out:$s)>; 5200 pred:$p, cc_out:$s)>; 5203 pred:$p, cc_out:$s)>; [all …]
|
| H A D | ARMInstrMVE.td | 264 ValueType Pred = pred; 2392 def : Pat<(v16i8 (vselect (v16i1 VCCR:$pred), 2397 def : Pat<(v8i16 (vselect (v8i1 VCCR:$pred), 2402 def : Pat<(v4i32 (vselect (v4i1 VCCR:$pred), 2407 def : Pat<(v4f32 (vselect (v4i1 VCCR:$pred), 2412 def : Pat<(v8f16 (vselect (v8i1 VCCR:$pred), 3707 defvar pred = (VTI.Pred VCCR:$pred); 5584 defvar pred = (VTI.Pred VCCR:$pred); 5626 defvar pred = (VTI.Pred VCCR:$pred); 6773 def : Pat<(v16i8 (zext (v16i1 VCCR:$pred))), [all …]
|
| H A D | ARMInstrNEON.td | 8790 pred:$p)>; 8793 pred:$p)>; 8796 pred:$p)>; 8799 pred:$p)>; 8802 pred:$p)>; 8805 pred:$p)>; 8810 pred:$p)>; 8814 pred:$p)>; 8818 pred:$p)>; 8822 pred:$p)>; [all …]
|
| H A D | ARMInstrThumb.td | 335 def : tHintAlias<"nop$p", (tHINT 0, pred:$p), 1>; // A8.6.110 337 def : tHintAlias<"wfe$p", (tHINT 2, pred:$p), 1>; // A8.6.408 338 def : tHintAlias<"wfi$p", (tHINT 3, pred:$p), 1>; // A8.6.409 340 def : tInstAlias<"sevl$p", (tHINT 5, pred:$p), 1> { 450 (tADDspi SP, t_imm0_508s4:$imm, pred:$p)>; 452 (tSUBspi SP, t_imm0_508s4:$imm, pred:$p)>; 550 def tBLXr : TI<(outs), (ins pred:$p, GPR:$func), IIC_Br, 657 (ins t_brtarget:$dst, pred:$p), 659 (tB t_brtarget:$dst, pred:$p)>, 1255 pred:$p)>; [all …]
|
| H A D | ARMInstrCDE.td | 191 let PredOp = !if(acc, (ins pred:$p), (ins)); 613 (VTI.Pred VCCR:$pred))), 615 (VTI.Pred VCCR:$pred), 619 (VTI.Pred VCCR:$pred))), 622 (VTI.Pred VCCR:$pred)))>; 627 (VTI.Pred VCCR:$pred))), 630 (VTI.Pred VCCR:$pred), 635 (VTI.Pred VCCR:$pred))), 644 (VTI.Pred VCCR:$pred))), 648 (VTI.Pred VCCR:$pred), [all …]
|
| H A D | ARMInstrInfo.td | 2427 (ins i32imm:$label, pred:$p), 4420 pred:$p, cc_out:$s)>, 4427 pred:$p, cc_out:$s)>, 5600 c_imm:$CRm, 0, pred:$p)>; 5608 c_imm:$CRm, 0, pred:$p)>; 6227 (SXTB GPRnopc:$Rd, GPRnopc:$Rm, 0, pred:$p)>; 6293 pred:$p, cc_out:$s)>; 6296 pred:$p, cc_out:$s)>; 6299 pred:$p, cc_out:$s)>; 6302 pred:$p, cc_out:$s)>; [all …]
|
| /freebsd-13.1/cddl/contrib/opensolaris/cmd/lockstat/ |
| H A D | lockstat.c | 598 if (*pred == NULL) { in predicate_add() 599 *pred = malloc(1); in predicate_add() 600 *pred[0] = '\0'; in predicate_add() 623 free(*pred); in predicate_add() 624 *pred = new; in predicate_add() 630 free(*pred); in predicate_destroy() 631 *pred = NULL; in predicate_destroy() 705 char *pred = NULL; in dprog_addevent() local 763 if (pred != NULL) in dprog_addevent() 782 pred = NULL; in dprog_addevent() [all …]
|
| /freebsd-13.1/bin/ed/ |
| H A D | ed.h | 160 #define REQUE(pred, succ) (pred)->q_forw = (succ), (succ)->q_back = (pred) argument 163 #define INSQUE(elem, pred) \ argument 165 REQUE((elem), (pred)->q_forw); \ 166 REQUE((pred), elem); \
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_cuda_intrinsics.h | 198 inline __device__ int __all_sync(unsigned int mask, int pred) { in __all_sync() argument 199 return __nvvm_vote_all_sync(mask, pred); in __all_sync() 202 inline __device__ int __any_sync(unsigned int mask, int pred) { in __any_sync() argument 203 return __nvvm_vote_any_sync(mask, pred); in __any_sync() 206 inline __device__ int __uni_sync(unsigned int mask, int pred) { in __uni_sync() argument 207 return __nvvm_vote_uni_sync(mask, pred); in __uni_sync() 210 inline __device__ unsigned int __ballot_sync(unsigned int mask, int pred) { in __ballot_sync() argument 211 return __nvvm_vote_ballot_sync(mask, pred); in __ballot_sync() 243 __match32_all_sync(unsigned int mask, unsigned int value, int *pred) { in __match32_all_sync() argument 244 return __nvvm_match_all_sync_i32p(mask, value, pred); in __match32_all_sync() [all …]
|
| /freebsd-13.1/contrib/llvm-project/libcxx/include/ |
| H A D | algorithm | 23 all_of(InputIterator first, InputIterator last, Predicate pred); 27 any_of(InputIterator first, InputIterator last, Predicate pred); 31 none_of(InputIterator first, InputIterator last, Predicate pred); 101 InputIterator2 first2, BinaryPredicate pred); 107 BinaryPredicate pred); // **C++14** 121 InputIterator2 first2, BinaryPredicate pred); 127 BinaryPredicate pred); // **C++14** 148 BinaryPredicate pred); // **C++14** 167 Size count, const T& value, BinaryPredicate pred); 176 OutputIterator result, Predicate pred); [all …]
|
| H A D | condition_variable | 35 void wait(unique_lock<mutex>& lock, Predicate pred); 46 Predicate pred); 57 Predicate pred); 80 void wait(Lock& lock, Predicate pred); 91 Predicate pred); 102 Predicate pred);
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/StaticAnalyzer/Core/ |
| H A D | ExplodedGraph.cpp | 92 const ExplodedNode *pred = *(node->pred_begin()); in shouldCollect() local 93 if (pred->succ_size() != 1) in shouldCollect() 116 ProgramStateRef pred_state = pred->getState(); in shouldCollect() 118 progPoint.getLocationContext() != pred->getLocationContext()) in shouldCollect() 160 ExplodedNode *pred = *(node->pred_begin()); in collectNode() local 162 pred->replaceSuccessor(succ); in collectNode() 163 succ->replacePredecessor(pred); in collectNode()
|
| /freebsd-13.1/cddl/usr.sbin/dtrace/tests/common/clauses/ |
| H A D | Makefile | 15 err.D_IDENT_UNDEF.pred.d \ 17 tst.pred.d \
|
| /freebsd-13.1/lib/libc/stdlib/ |
| H A D | insque.c | 21 insque(void *element, void *pred) in insque() argument 26 prev = (struct que_elem *)pred; in insque()
|
| /freebsd-13.1/sys/kern/ |
| H A D | subr_rangeset.c | 132 rs_pred_t pred) in rangeset_remove_pred() argument 159 if (pred(rs->rs_data_ctx, r)) in rangeset_remove_pred() 169 if (pred(rs->rs_data_ctx, r)) { in rangeset_remove_pred() 182 if (pred(rs->rs_data_ctx, r)) { in rangeset_remove_pred() 205 if (pred(rs->rs_data_ctx, r)) { in rangeset_remove_pred()
|
| /freebsd-13.1/contrib/llvm-project/llvm/include/llvm/ProfileData/ |
| H A D | GCOV.h | 252 uint64_t propagateCounts(const GCOVBlock &v, GCOVArc *pred); 287 void addSrcEdge(GCOVArc *Edge) { pred.push_back(Edge); } in addSrcEdge() 292 return make_range(pred.begin(), pred.end()); in srcs() 311 SmallVector<GCOVArc *, 2> pred; variable
|
| /freebsd-13.1/contrib/libpcap/ |
| H A D | optimize.c | 1506 oval1 = ep->pred->oval; in fold_edge() 1610 val = ep->pred->val[A_ATOM]; in or_pullup() 1674 if (JT(ep->pred) == b) in or_pullup() 1675 JT(ep->pred) = pull; in or_pullup() 1677 JF(ep->pred) = pull; in or_pullup() 1701 val = ep->pred->val[A_ATOM]; in and_pullup() 1765 if (JT(ep->pred) == b) in and_pullup() 1766 JT(ep->pred) = pull; in and_pullup() 1768 JF(ep->pred) = pull; in and_pullup() 2206 b->et.pred = b; in opt_init() [all …]
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/StaticAnalyzer/Checkers/ |
| H A D | UnreachableCodeChecker.cpp | 230 const CFGBlock *pred = *CB->pred_begin(); in isInvalidPath() local 231 if (!pred) in isInvalidPath() 235 const Stmt *cond = pred->getTerminatorCondition(); in isInvalidPath()
|